#region using

using System;
using System.Text;
using System.Web;
using BlogEngine.Core;
using BlogEngine.Core.Web.Controls;

#endregion

/// <summary>
/// Adds an Odiogo 'Listen' image button to the top of all posts.
/// </summary>
[Extension("Adds an Odiogo 'Listen' image button to the top of all posts", "1.0", "Mads Kristensen")]
public class Odiogo
{

	/// <summary>
	/// Change this variable to your own Odiogo feed ID. You can only use your own ID.
	/// You only need to change this one variable to make it work. 
	/// </summary>
	private const int ODIOGO_FEED_ID = 40624;

	/// <summary>
	/// Initializes a new instance of the <see cref="Odiogo"/> class.
	/// </summary>
	public Odiogo()
  {
		Post.Serving += new EventHandler<ServingEventArgs>(Post_Serving);
  }

	/// <summary>
	/// Handles the Serving event of the Post object.
	/// </summary>
	void Post_Serving(object sender, ServingEventArgs e)
	{
		if (e.Location == ServingLocation.PostList || e.Location == ServingLocation.SinglePost)
		{
			Post post = (Post)sender;
			string script = string.Format(SCRIPT, ODIOGO_FEED_ID, post.Title.Replace("'", "\\'"), post.Id.ToString());
			e.Body = script + e.Body;

			AddOdiogoScript();
		}
	}

	/// <summary>
	/// Adds the odiogo script to the page header.
	/// </summary>
	private static void AddOdiogoScript()
	{
		HttpContext context = HttpContext.Current;
		// Make sure we haven't already added the script to the page header.
		if (context.Items["odiogo"] == null)
		{
			System.Web.UI.Page page = (System.Web.UI.Page)context.CurrentHandler;
			string js = string.Format("<script type=\"text/javascript\" src=\"http://podcasts.odiogo.com/odiogo_js.php?feed_id={0}&platform=be\"></script>", ODIOGO_FEED_ID);
			page.Header.Controls.Add(new System.Web.UI.LiteralControl(js));
			context.Items["odiogo"] = 1;
		}
	}

	private static readonly string SCRIPT = CreateScript();

	/// <summary>
	/// Creates the script used to display the image button.
	/// </summary>
	private static string CreateScript()
	{
		StringBuilder sb = new StringBuilder();
		sb.AppendLine("<div class=\"odiogo\">");
		sb.AppendLine("<script type=\"text/javascript\">");
		sb.AppendLine("<!--");
		sb.AppendLine("showOdiogoReadNowButton ('{0}', '{1}', '{2}', 290, 55);");
		sb.AppendLine("//-->");
		sb.AppendLine("</script><br />");
		sb.AppendLine("<script type=\"text/javascript\">");
		sb.AppendLine("showInitialOdiogoReadNowFrame ('{0}', '{2}', 290, 0);");
		sb.AppendLine("//-->");
		sb.AppendLine("</script>");
		sb.AppendLine("</div>");

		return sb.ToString();
	}

}